@@ -8,7 +8,9 @@ use Carp qw(croak carp confess);
 use Devel::InnerPackage;
 use vars qw($VERSION);
 
-$VERSION = '4.4';
+use if $] > 5.017, 'deprecate';
+
+$VERSION = '4.8';
 
 
 sub new {
@@ -77,20 +79,21 @@ sub plugins {
         $plugins{$_} = 1;
     }
 
-    # are we instantiating or requring?
+    # are we instantiating or requiring?
     if (defined $self->{'instantiate'}) {
         my $method = $self->{'instantiate'};
         my @objs   = ();
-        foreach my $package (keys %plugins) {
-			next unless $package->can($method);
+        foreach my $package (sort keys %plugins) {
+            next unless $package->can($method);
             my $obj = eval { $package->$method(@_) };
-	        $self->{'on_instantiate_error'}->($package, $@) if $@;
+            $self->{'on_instantiate_error'}->($package, $@) if $@;
             push @objs, $obj if $obj;           
         }
         return @objs;
     } else { 
         # no? just return the names
-        return keys %plugins;
+        my @objs= sort keys %plugins;
+        return @objs;
     }
 }
 
